@@ -273,6 +273,7 @@ parse_int64(const char *value, int64 *result)
 #elif defined(HAVE_LONG_INT_64)
 	val = strtol(value, &endptr, 0);
 #elif defined(HAVE_LONG_LONG_INT_64)
+	val = strtoll(value, &endptr, 0);
 #else
 	val = strtol(value, &endptr, 0);
 #endif
@@ -350,6 +351,7 @@ parse_time(const char *value, time_t *time)
 	tmp[len] = '\0';
 
 	/* parse for "YYYY-MM-DD HH:MI:SS" */
+	memset(&tm, 0, sizeof(tm));
 	tm.tm_year = 0;		/* tm_year is year - 1900 */
 	tm.tm_mon = 0;		/* tm_mon is 0 - 11 */
 	tm.tm_mday = 1;		/* tm_mday is 1 - 31 */
@@ -374,6 +376,9 @@ parse_time(const char *value, time_t *time)
 	if (i > 1)
 		tm.tm_mon -= 1;
 
+	/* determine whether Daylight Saving Time is in effect */
+	tm.tm_isdst = -1;
+
 	*time = mktime(&tm);
 
 	return true;
@@ -397,11 +402,15 @@ PGconn *
 pgut_connect(const char *info, YesNo prompt, int elevel)
 {
 	char	   *passwd;
-
-	CHECK_FOR_INTERRUPTS();
+	StringInfoData add_pass;
 
 	if (prompt == YES)
+	{
 		passwd = prompt_for_password();
+		initStringInfo(&add_pass);
+		appendStringInfo(&add_pass, info);
+		appendStringInfo(&add_pass, " password=%s ", passwd);
+	}
 	else
 		passwd = NULL;
 
@@ -409,15 +418,17 @@ pgut_connect(const char *info, YesNo prompt, int elevel)
 	for (;;)
 	{
 		PGconn	   *conn;
+		CHECK_FOR_INTERRUPTS();
 
-		conn = PQconnectdb(info);
+		if(!passwd)
+			conn = PQconnectdb(info);
+		else
+			conn = PQconnectdb(add_pass.data);
 
 		if (PQstatus(conn) == CONNECTION_OK)
 		{
 			pgutConn *c;
 
-			free(passwd);
-
 			c = pgut_new(pgutConn);
 			c->conn = conn;
 			c->cancel = NULL;
@@ -427,6 +438,10 @@ pgut_connect(const char *info, YesNo prompt, int elevel)
 			pgut_connections = c;
 			pgut_conn_unlock();
 
+			if(passwd)
+				termStringInfo(&add_pass);
+
+			free(passwd);
 			return conn;
 		}
 
@@ -435,6 +450,9 @@ pgut_connect(const char *info, YesNo prompt, int elevel)
 			PQfinish(conn);
 			free(passwd);
 			passwd = prompt_for_password();
+ 			initStringInfo(&add_pass);
+			appendStringInfo(&add_pass, info);
+			appendStringInfo(&add_pass, " password=%s ", passwd);
 			continue;
 		}
 		ereport(elevel,
